@@ -147,57 +147,3 @@ print.netlogit <- function(x, ...){
   cat("\n# Model summary statistics\n")
   print(glance(x))
 }
-
-#' @export
-plot.netlm <- function(x, ...){
-  distrib <- x$dist
-  distrib <- as.data.frame(distrib)
-  names(distrib) <- x$names
-  distrib$obs <- seq_len(nrow(distrib))
-  distrib <- stats::reshape(data = distrib, # tidyr::pivot_longer replacement
-                     direction = "long",
-                     varying = colnames(distrib)[-ncol(distrib)],
-                     v.names = "value",
-                     times = colnames(distrib)[-ncol(distrib)],
-                     timevar = "name")
-  rownames(distrib) <- NULL
-  distrib$id <- NULL
-  distrib <- dplyr::arrange(distrib, obs)
-  distrib$coef <- rep(unname(x$coefficients), nrow(x$dist))
-  distrib$tstat <- rep(unname(x$tstat), nrow(x$dist))
-  distrib$name <- factor(distrib$name, x$names)
-  ggplot2::ggplot(distrib, ggplot2::aes(.data$value, .data$name)) + 
-    ggplot2::geom_violin(draw_quantiles = c(0.025, 0.975)) + 
-    ggplot2::theme_minimal() +
-    ylab("") + xlab("Statistic") + 
-    ggplot2::geom_point(aes(x = .data$tstat), size = 2, 
-                        colour = "red") +
-    scale_y_discrete(limits=rev)
-}
-
-#' @export
-plot.netlogit <- function(x, ...){
-  distrib <- x$dist
-  distrib <- as.data.frame(distrib)
-  names(distrib) <- x$names
-  distrib$obs <- seq_len(nrow(distrib))
-  distrib <- stats::reshape(data = distrib, # tidyr::pivot_longer replacement
-                     direction = "long",
-                     varying = colnames(distrib)[-ncol(distrib)],
-                     v.names = "value",
-                     times = colnames(distrib)[-ncol(distrib)],
-                     timevar = "name")
-  rownames(distrib) <- NULL
-  distrib$id <- NULL
-  distrib <- dplyr::arrange(distrib, obs)
-  distrib$coef <- rep(unname(x$coefficients), nrow(x$dist))
-  distrib$tstat <- rep(unname(x$tstat), nrow(x$dist))
-  distrib$name <- factor(distrib$name, x$names)
-  ggplot2::ggplot(distrib, ggplot2::aes(.data$value, .data$name)) + 
-    ggplot2::geom_violin(draw_quantiles = c(0.025, 0.975)) + 
-    ggplot2::theme_minimal() +
-    ylab("") + xlab("Statistic") + 
-    ggplot2::geom_point(aes(x = .data$tstat), size = 2, 
-                        colour = "red") +
-    scale_y_discrete(limits=rev)
-}
